@@ -2,7 +2,6 @@ import time
 
 from openshift.dynamic.exceptions import ConflictError
 
-from ocp_resources.constants import TIMEOUT_4MINUTES
 from ocp_resources.logger import get_logger
 from ocp_resources.resource import Resource
 from ocp_resources.utils import TimeoutSampler
@@ -11,38 +10,27 @@ from ocp_resources.utils import TimeoutSampler
 LOGGER = get_logger(name=__name__)
 
 SLEEP = 1
+TIMEOUT = 240
 
 
 class NodeNetworkState(Resource):
     api_group = Resource.ApiGroup.NMSTATE_IO
 
-    def __init__(
-        self,
-        name=None,
-        client=None,
-        teardown=True,
-        yaml_file=None,
-        delete_timeout=TIMEOUT_4MINUTES,
-        **kwargs,
-    ):
-        super().__init__(
-            name=name,
-            client=client,
-            teardown=teardown,
-            yaml_file=yaml_file,
-            delete_timeout=delete_timeout,
-            **kwargs,
-        )
+    def __init__(self, name, client=None, teardown=True):
+        super().__init__(name=name, client=client, teardown=teardown)
         status = self.instance.to_dict()["status"]
-        self.desired_state = status.get("desiredState", {"interfaces": []})
+        if "desiredState" in status:
+            self.desired_state = status["desiredState"]
+        else:
+            self.desired_state = {"interfaces": []}
 
     def set_interface(self, interface):
 
         # First drop the interface is's already in the list
         interfaces = [
-            iface
-            for iface in self.desired_state["interfaces"]
-            if iface["name"] != interface["name"]
+            i
+            for i in self.desired_state["interfaces"]
+            if not (i["name"] == interface["name"])
         ]
 
         # Add the interface
@@ -51,9 +39,6 @@ class NodeNetworkState(Resource):
 
     def to_dict(self):
         res = super().to_dict()
-        if self.yaml_file:
-            return res
-
         res.update(
             {
                 "spec": {
@@ -89,7 +74,7 @@ class NodeNetworkState(Resource):
 
         LOGGER.info(f"Checking if interface {name} is up -- {self.name}")
         samples = TimeoutSampler(
-            wait_timeout=TIMEOUT_4MINUTES, sleep=SLEEP, func=_find_up_interface
+            wait_timeout=TIMEOUT, sleep=SLEEP, func=_find_up_interface
         )
         for sample in samples:
             if sample:
@@ -98,10 +83,7 @@ class NodeNetworkState(Resource):
     def wait_until_deleted(self, name):
         LOGGER.info(f"Checking if interface {name} is deleted -- {self.name}")
         samples = TimeoutSampler(
-            wait_timeout=self.delete_timeout,
-            sleep=SLEEP,
-            func=self.get_interface,
-            name=name,
+            wait_timeout=TIMEOUT, sleep=SLEEP, func=self.get_interface, name=name
         )
         for sample in samples:
             if not sample:
