@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from ocp_resources.constants import TIMEOUT_4MINUTES
+
 from ocp_resources.logger import get_logger
 from ocp_resources.resource import NamespacedResource
 
@@ -15,30 +15,13 @@ class UploadTokenRequest(NamespacedResource):
 
     api_group = NamespacedResource.ApiGroup.UPLOAD_CDI_KUBEVIRT_IO
 
-    def __init__(
-        self,
-        name=None,
-        namespace=None,
-        client=None,
-        pvc_name=None,
-        teardown=True,
-        yaml_file=None,
-        delete_timeout=TIMEOUT_4MINUTES,
-    ):
+    def __init__(self, name, namespace, client=None, pvc_name=None, teardown=True):
         super().__init__(
-            name=name,
-            namespace=namespace,
-            client=client,
-            teardown=teardown,
-            yaml_file=yaml_file,
-            delete_timeout=delete_timeout,
+            name=name, namespace=namespace, client=client, teardown=teardown
         )
         self.pvc_name = pvc_name
 
     def to_dict(self):
         res = super().to_dict()
-        if self.yaml_file:
-            return res
-
         res.update({"spec": {"pvcName": self.pvc_name}})
         return res
