@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 
 
-from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT, TIMEOUT_4MINUTES
+from urllib3.exceptions import ProtocolError
+
 from ocp_resources.logger import get_logger
 from ocp_resources.resource import NamespacedResource
 from ocp_resources.utils import TimeoutExpiredError, TimeoutSampler
@@ -89,10 +90,10 @@ class VirtualMachineImport(NamespacedResource):
 
     def __init__(
         self,
-        name=None,
-        namespace=None,
-        provider_credentials_secret_name=None,
-        provider_type=None,
+        name,
+        namespace,
+        provider_credentials_secret_name,
+        provider_type,
         provider_credentials_secret_namespace=None,
         client=None,
         teardown=True,
@@ -108,8 +109,6 @@ class VirtualMachineImport(NamespacedResource):
         warm=False,
         finalize_date=None,
         privileged_client=None,
-        yaml_file=None,
-        delete_timeout=TIMEOUT_4MINUTES,
     ):
         super().__init__(
             name=name,
@@ -117,8 +116,6 @@ class VirtualMachineImport(NamespacedResource):
             client=client,
             teardown=teardown,
             privileged_client=privileged_client,
-            yaml_file=yaml_file,
-            delete_timeout=delete_timeout,
         )
         self.vm_id = vm_id
         self.vm_name = vm_name
@@ -148,9 +145,6 @@ class VirtualMachineImport(NamespacedResource):
 
     def to_dict(self):
         res = super().to_dict()
-        if self.yaml_file:
-            return res
-
         spec = res.setdefault("spec", {})
 
         secret = spec.setdefault("providerCredentialsSecret", {})
@@ -231,8 +225,8 @@ class VirtualMachineImport(NamespacedResource):
         samples = TimeoutSampler(
             wait_timeout=timeout,
             sleep=1,
-            exceptions_dict=PROTOCOL_ERROR_EXCEPTION_DICT,
-            func=self.api.get,
+            exceptions=ProtocolError,
+            func=self.api().get,
             field_selector=f"metadata.name=={self.name}",
             namespace=self.namespace,
         )
@@ -270,29 +264,14 @@ class ResourceMapping(NamespacedResource):
 
     api_group = NamespacedResource.ApiGroup.V2V_KUBEVIRT_IO
 
-    def __init__(
-        self,
-        name=None,
-        namespace=None,
-        mapping=None,
-        client=None,
-        teardown=True,
-        yaml_file=None,
-    ):
+    def __init__(self, name, namespace, mapping, client=None, teardown=True):
         super().__init__(
-            name=name,
-            namespace=namespace,
-            client=client,
-            teardown=teardown,
-            yaml_file=yaml_file,
+            name=name, namespace=namespace, client=client, teardown=teardown
         )
         self.mapping = mapping
 
     def to_dict(self):
         res = super().to_dict()
-        if self.yaml_file:
-            return res
-
         for provider, mapping in self.mapping.items():
             res_provider_section = res.setdefault("spec", {}).setdefault(provider, {})
             if mapping.network_mappings is not None:
